# -*- coding: ascii -*-
#
#  showingsurface.py - Showing SVG file
#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
#  Copyright (C) 2004 by Takuya KAWAHARA <num@sann.ne.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#
# $Id: showingsurface.py,v 1.4 2004/08/30 06:59:01 atzm Exp $
#

import gtk, pango

from common import *
from viewer.viewercommon import *

class ShowingSurface:
	def button_press(self, darea=None, event=None):
		if event.type == 5:
			return
		x = int(event.x) / SIZE_SURFACE_H
		y = int(event.y) / SIZE_SURFACE_V
		w = self.width   / SIZE_SURFACE_H
		h = self.height  / SIZE_SURFACE_V
		splite = (y * w) + x
		try:
			self.app.insert(r'\s[%d]' % self.ghost.reverse_dic[splite])
		except:
			pass

	def expose(self, darea=None, event=None):
		style = self.drawingarea.get_style()
		fg_gc = style.fg_gc[gtk.STATE_NORMAL]
		bg_gc = style.bg_gc[gtk.STATE_NORMAL]
		self.drawingarea.window.draw_drawable(bg_gc, self.pixmap,
											  0, 0, 0, 0, -1, -1)
		self.draw_number(fg_gc, bg_gc)
		return gtk.TRUE

	def draw_number(self, fg_gc, bg_gc):
		num_x = self.width  / SIZE_SURFACE_H
		num_y = self.height / SIZE_SURFACE_V

		self.ghost.set_reverse_dic()
		i = 0
		for y in range(num_y):
			for x in range(num_x):
				layout = pango.Layout(self.drawingarea.get_pango_context())
				try:
					layout.set_text('%d' % self.ghost.reverse_dic[i])
					[w, h] = layout.get_pixel_size()
					self.drawingarea.window.draw_rectangle(bg_gc, gtk.TRUE,
														   x * SIZE_SURFACE_H,
														   y * SIZE_SURFACE_V,
														   w, h)
					self.drawingarea.window.draw_layout(fg_gc,
														x * SIZE_SURFACE_H,
														y * SIZE_SURFACE_V,
														layout)
				except KeyError:
					pass
				i += 1

	def __init__(self, app, pixbuf, ghost):
		self.app    = app
		self.pixbuf = pixbuf
		self.ghost  = ghost
		self.width  = self.pixbuf.get_width()
		self.height = self.pixbuf.get_height()
		self.pixmap = self.pixbuf.render_pixmap_and_mask()[0]

		self.drawingarea = gtk.DrawingArea()
		self.drawingarea.set_events(gtk.gdk.EXPOSURE_MASK|gtk.gdk.BUTTON_PRESS_MASK)
		self.drawingarea.connect('expose-event', self.expose)
		self.drawingarea.connect('button-press-event', self.button_press)
		self.drawingarea.show()

		self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
		self.window.set_title('%s: %s: %s' % (unicode(_(APP), "utf-8"),
										  unicode(_("All surfaces"), "utf-8"),
										  self.ghost.get_ghostname()))
		self.window.set_size_request(self.width, self.height)
		self.window.connect('destroy', lambda x: x.destroy())
		self.window.add(self.drawingarea)
		self.window.show()
